pub struct GetFileOptions {
pub path: String,
pub encoding: Option<Encoding>,
}Expand description
Specifies the options when getting a file.
It contains a path field for the file path and an encoding field for the file encoding.
Fields
path: StringThe path of the file to get.
encoding: Option<Encoding>The encoding of the file. This is an optional field.